@@ -74,10 +74,8 @@ INTERNAL_USERS = [
     "chaiversetests",
     "Jellywibble",
     "rirv938",
-    "NischayDnk",
     "richhx",
-    "fanghan0520",
-    "ChaiHarshitSheoran"
+    "qdv206",
 ]
 
 
