@@ -36,3 +36,8 @@ def is_base_64(string):
     except:
         is_base_64 = False
     return is_base_64
+
+
+class class_property(property):
+    def __get__(self, owner_self, owner_cls):
+        return self.fget(owner_cls)
