@@ -1,10 +1,10 @@
 import itertools
 import sys
 import time
-from typing import List, Optional, Set
+from typing import Any, List, Optional, Set
 
 from dill.source import getsource
-from pydantic import BaseModel, Extra, Field, PrivateAttr, validator, field_validator
+from pydantic import BaseModel, Extra, Field, PrivateAttr, validator, field_validator, model_validator
 
 
 from chaiverse import config, errors, formatters, utils
@@ -179,7 +179,7 @@ class GenerationParams(BaseModel, extra=Extra.allow, title=''):
 
     def _validate_max_output_tokens(self):
         allowed_min = 1
-        allowed_max = 64
+        allowed_max = 80
 
         is_not_none = self.max_input_tokens is not None
         is_not_in_correct_range = not (allowed_min <= self.max_output_tokens <= allowed_max)
@@ -408,7 +408,13 @@ class ModelSubmitter:
 
 
 class FunctionResponse(BaseModel):
-    completions: List[str]
+    @model_validator(mode="before")
+    def convert_completions(cls, data):
+        if data.get("completions"):
+            data["predictions"] = data.pop("completions")
+        return data
+
+    predictions: Optional[List[Any]] = None
     metadata: dict
 
 
